@@ -5,7 +5,7 @@ from __future__ import annotations
 import logging
 
 from ._internal.run import CmdLoggingAdapter
-from .sync.base import BaseSync
+from .sync.base import BaseSync, SyncError, SyncResult
 from .sync.git import GitSync
 from .sync.hg import HgSync
 from .sync.svn import SvnSync
@@ -16,6 +16,8 @@ __all__ = [
     "GitSync",
     "HgSync",
     "SvnSync",
+    "SyncError",
+    "SyncResult",
 ]
 
 logger = logging.getLogger(__name__)
