@@ -37,7 +37,6 @@ def console_to_str(s: bytes) -> str:
 
 if t.TYPE_CHECKING:
     _LoggerAdapter = logging.LoggerAdapter[logging.Logger]
-    from typing import TypeAlias
 else:
     _LoggerAdapter = logging.LoggerAdapter
 
@@ -96,12 +95,12 @@ class ProgressCallbackProtocol(t.Protocol):
 
 
 if sys.platform == "win32":
-    _ENV: TypeAlias = Mapping[str, str]
+    _ENV: t.TypeAlias = Mapping[str, str]
 else:
-    _ENV: TypeAlias = Mapping[bytes, StrPath] | Mapping[str, StrPath]
+    _ENV: t.TypeAlias = Mapping[bytes, StrPath] | Mapping[str, StrPath]
 
 _CMD = StrPath | Sequence[StrPath]
-_FILE: TypeAlias = int | t.IO[t.Any] | None
+_FILE: t.TypeAlias = int | t.IO[t.Any] | None
 
 
 def run(
@@ -158,12 +157,12 @@ def run(
         subprocess in real time instead of when the process finishes.
 
     check_returncode : bool
-        Indicate whether a `libvcs.exc.CommandError` should be raised if return code is
-        different from 0.
+        Indicate whether a ``libvcs.exc.CommandError`` should be raised if return
+        code is different from 0.
 
     callback : ProgressCallbackProtocol
         callback to return output as a command executes, accepts a function signature
-        of `(output, timestamp)`. Example usage::
+        of ``(output, timestamp)``. Example usage::
 
             def progress_cb(output, timestamp):
                 sys.stdout.write(output)
@@ -172,7 +171,7 @@ def run(
 
     Upcoming changes
     ----------------
-    When minimum python >= 3.10, `pipesize: int = -1` will be added after `umask`.
+    When minimum python >= 3.10, pipesize: int = -1 will be added after umask.
     """
     proc = subprocess.Popen(
         args,
